@@ -19,7 +19,8 @@ admiral_environment <- new.env(parent = emptyenv())
 ## set_admiral_options
 admiral_environment$admiral_options <- list(
   # future_input = exprs(...), nolint
-  subject_keys = exprs(STUDYID, USUBJID)
+  subject_keys = exprs(STUDYID, USUBJID),
+  signif_digits = 15
 )
 
 # To enhance features and add inputs as necessary
