@@ -27,8 +27,12 @@ call_user_fun <- function(call) {
   tryCatch(
     eval_tidy(call),
     error = function(cnd) {
-      abort(
-        paste0("Calling ", as_label(enexpr(call)), " caused the following error:\n", cnd)
+      cli_abort(
+        message = c(
+          "Calling {.code {as_label(enexpr(call))}} caused the following error:",
+          conditionMessage(cnd)
+        ),
+        call = parent.frame(n = 4)
       )
     }
   )
