@@ -79,7 +79,7 @@ pc_dates <- pc %>%
     NFRLT = if_else(PCTPTNUM < 0, 0, PCTPTNUM), .after = USUBJID
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   pc_dates,
   display_vars = exprs(
@@ -115,7 +115,10 @@ ex_dates <- ex %>%
   # Derive event ID and nominal relative time from first dose (NFRLT)
   mutate(
     EVID = 1,
-    NFRLT = 24 * (VISITDY - 1), .after = USUBJID
+    NFRLT = case_when(
+      VISITDY == 1 ~ 0,
+      TRUE ~ 24 * VISITDY
+    )
   ) %>%
   # Set missing end dates to start date
   mutate(AENDTM = case_when(
@@ -126,7 +129,7 @@ ex_dates <- ex %>%
   derive_vars_dtm_to_dt(exprs(ASTDTM)) %>%
   derive_vars_dtm_to_dt(exprs(AENDTM))
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   ex_dates,
   display_vars = exprs(
@@ -169,7 +172,7 @@ ex_exp <- ex_dates %>%
   derive_vars_dtm_to_tm(exprs(AENDTM)) %>%
   derive_vars_dy(reference_date = TRTSDT, source_vars = exprs(ADT))
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   ex_exp,
   display_vars = exprs(
@@ -199,7 +202,7 @@ adpc_first_dose <- pc_dates %>%
     AVISIT = paste("Day", AVISITN)
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adpc_first_dose,
   display_vars = exprs(
@@ -220,13 +223,14 @@ adpc_prev <- adpc_first_dose %>%
       AENDTM_prev = AENDTM
     ),
     join_vars = exprs(ADTM),
+    join_type = "all",
     filter_add = NULL,
     filter_join = ADTM > ADTM.join,
     mode = "last",
     check_type = "none"
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adpc_prev,
   display_vars = exprs(
@@ -247,13 +251,14 @@ adpc_next <- adpc_prev %>%
       AENDTM_next = AENDTM
     ),
     join_vars = exprs(ADTM),
+    join_type = "all",
     filter_add = NULL,
     filter_join = ADTM <= ADTM.join,
     mode = "first",
     check_type = "none"
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adpc_next,
   display_vars = exprs(
@@ -272,6 +277,7 @@ adpc_nom_prev <- adpc_next %>%
     order = exprs(NFRLT),
     new_vars = exprs(NFRLT_prev = NFRLT),
     join_vars = exprs(NFRLT),
+    join_type = "all",
     filter_add = NULL,
     filter_join = NFRLT > NFRLT.join,
     mode = "last",
@@ -287,13 +293,14 @@ adpc_nom_next <- adpc_nom_prev %>%
     order = exprs(NFRLT),
     new_vars = exprs(NFRLT_next = NFRLT),
     join_vars = exprs(NFRLT),
+    join_type = "all",
     filter_add = NULL,
     filter_join = NFRLT <= NFRLT.join,
     mode = "first",
     check_type = "none"
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adpc_nom_next,
   display_vars = exprs(
@@ -362,7 +369,7 @@ adpc_arrlt <- bind_rows(adpc_nom_next, ex_exp) %>%
   derive_vars_dtm_to_dt(exprs(PCRFTDTM)) %>%
   derive_vars_dtm_to_tm(exprs(PCRFTDTM))
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adpc_arrlt,
   display_vars = exprs(
@@ -385,7 +392,7 @@ adpc_nrrlt <- adpc_arrlt %>%
     )
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adpc_nrrlt,
   display_vars = exprs(
@@ -402,6 +409,7 @@ dataset_vignette(
 
 adpc_aval <- adpc_nrrlt %>%
   mutate(
+    PARCAT1 = PCSPEC,
     ATPTN = case_when(
       EVID == 1 ~ 0,
       TRUE ~ PCTPTNUM
@@ -463,7 +471,7 @@ adpc_aval <- adpc_nrrlt %>%
     SRCSEQ = coalesce(PCSEQ, EXSEQ)
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adpc_aval,
   display_vars = exprs(
@@ -487,14 +495,14 @@ dtype <- adpc_aval %>%
     DOSEA = EXDOSE_next,
     BASETYPE = paste(AVISIT_next, "Baseline"),
     ATPT = "Pre-dose",
-    ATPTN = NFRLT,
+    ATPTN = -0.5,
     ABLFL = "Y",
     DTYPE = "COPY"
   ) %>%
   derive_vars_dtm_to_dt(exprs(PCRFTDTM)) %>%
   derive_vars_dtm_to_tm(exprs(PCRFTDTM))
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   dtype,
   display_vars = exprs(
@@ -514,7 +522,7 @@ adpc_dtype <- bind_rows(adpc_aval, dtype) %>%
     ANL02FL = if_else(is.na(DTYPE), "Y", NA_character_),
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 adpc_dtype %>%
   dataset_vignette(display_vars = exprs(
     STUDYID, USUBJID, BASETYPE, ADTM, ATPT, NFRLT, NRRLT, ARRLT, MRRLT
@@ -526,7 +534,7 @@ adpc_dtype %>%
 adpc_base <- adpc_dtype %>%
   # Derive BASE
   derive_var_base(
-    by_vars = exprs(STUDYID, USUBJID, PARAMCD, BASETYPE),
+    by_vars = exprs(STUDYID, USUBJID, PARAMCD, PARCAT1, BASETYPE),
     source_var = AVAL,
     new_var = BASE,
     filter = ABLFL == "Y"
@@ -541,7 +549,7 @@ adpc_aseq <- adpc_chg %>%
   derive_var_obs_number(
     new_var = ASEQ,
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(ADTM, BASETYPE, EVID, AVISITN, ATPTN, DTYPE),
+    order = exprs(ADTM, BASETYPE, EVID, AVISITN, ATPTN, PARCAT1, DTYPE),
     check_type = "error"
   ) %>%
   # Remove temporary variables
@@ -555,7 +563,7 @@ adpc_aseq <- adpc_chg %>%
     dataset_add = select(param_lookup, -PCTESTCD), by_vars = exprs(PARAMCD)
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 adpc_aseq %>%
   dataset_vignette(display_vars = exprs(
     USUBJID, BASETYPE, DTYPE, AVISIT, ATPT, AVAL, NFRLT, NRRLT, AFRLT, ARRLT, BASE, CHG
@@ -581,7 +589,7 @@ adpc_baselines <- adpc_aseq %>%
     BMIBLU = "kg/m^2"
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 adpc_baselines %>%
   dataset_vignette(display_vars = exprs(
     USUBJID, HTBL, HTBLU, WTBL, WTBLU, BMIBL, BMIBLU, BASETYPE, ATPT, AVAL
@@ -617,7 +625,7 @@ adppk_first_dose <- pc_dates %>%
     AVISIT = paste("Day", AVISITN),
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adppk_first_dose,
   display_vars = exprs(
@@ -638,6 +646,7 @@ adppk_prev <- adppk_first_dose %>%
       AENDTM_prev = AENDTM
     ),
     join_vars = exprs(ADTM),
+    join_type = "all",
     filter_add = NULL,
     filter_join = ADTM > ADTM.join,
     mode = "last",
@@ -653,13 +662,14 @@ adppk_nom_prev <- adppk_prev %>%
     order = exprs(NFRLT),
     new_vars = exprs(NFRLT_prev = NFRLT),
     join_vars = exprs(NFRLT),
+    join_type = "all",
     filter_add = NULL,
     filter_join = NFRLT > NFRLT.join,
     mode = "last",
     check_type = "none"
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adppk_nom_prev,
   display_vars = exprs(
@@ -713,7 +723,7 @@ adppk_aprlt <- bind_rows(adppk_nom_prev, ex_exp) %>%
     )
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adppk_aprlt,
   display_vars = exprs(
@@ -749,7 +759,8 @@ adppk_aval <- adppk_aprlt %>%
     # Derive CMT
     CMT = case_when(
       EVID == 1 ~ 1,
-      TRUE ~ 2
+      PCSPEC == "PLASMA" ~ 2,
+      TRUE ~ 3
     ),
     # Derive BLQFL/BLQFN
     BLQFL = case_when(
@@ -786,7 +797,7 @@ adppk_aval <- adppk_aprlt %>%
     SS = if_else(EVID == 1, 1, 0)
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adppk_aval,
   display_vars = exprs(
@@ -802,7 +813,7 @@ adppk_aseq <- adppk_aval %>%
   derive_var_obs_number(
     new_var = ASEQ,
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(AFRLT, EVID),
+    order = exprs(AFRLT, EVID, CMT),
     check_type = "error"
   ) %>%
   # Derive PARAM and PARAMN
@@ -816,11 +827,11 @@ adppk_aseq <- adppk_aval %>%
     -DOMAIN, -starts_with("min"), -starts_with("max"), -starts_with("EX"),
     -starts_with("PC"), -ends_with("first"), -ends_with("prev"),
     -ends_with("DTM"), -ends_with("DT"), -ends_with("TM"), -starts_with("VISIT"),
-    -starts_with("AVISIT"), -starts_with("PARAM"),
-    -ends_with("TMF"), -starts_with("TRT"), -starts_with("ATPT"), -DRUG
+    -starts_with("AVISIT"), -ends_with("TMF"), -starts_with("TRT"),
+    -starts_with("ATPT"), -DRUG
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adppk_aseq,
   display_vars = exprs(
@@ -833,6 +844,11 @@ dataset_vignette(
 # Include numeric values for STUDYIDN, USUBJIDN, SEXN, RACEN etc.
 
 covar <- adsl %>%
+  derive_vars_merged(
+    dataset_add = country_code_lookup,
+    new_vars = exprs(COUNTRYN = country_number, COUNTRYL = country_name),
+    by_vars = exprs(COUNTRY = country_code),
+  ) %>%
   mutate(
     STUDYIDN = as.numeric(word(USUBJID, 1, sep = fixed("-"))),
     SITEIDN = as.numeric(word(USUBJID, 2, sep = fixed("-"))),
@@ -879,26 +895,19 @@ covar <- adsl %>%
     FORMN = case_when(
       FORM == "PATCH" ~ 3,
       TRUE ~ 4
-    ),
-    COUNTRYN = case_when(
-      COUNTRY == "USA" ~ 1,
-      COUNTRY == "CAN" ~ 2,
-      COUNTRY == "GBR" ~ 3
-    ),
-    REGION1N = COUNTRYN,
+    )
   ) %>%
   select(
     STUDYID, STUDYIDN, SITEID, SITEIDN, USUBJID, USUBJIDN,
     SUBJID, SUBJIDN, AGE, SEX, SEXN, COHORT, COHORTC, ROUTE, ROUTEN,
-    RACE, RACEN, ETHNIC, ETHNICN, FORM, FORMN, COUNTRY, COUNTRYN,
-    REGION1, REGION1N
+    RACE, RACEN, ETHNIC, ETHNICN, FORM, FORMN, COUNTRY, COUNTRYN, COUNTRYL
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   covar,
   display_vars = exprs(
-    STUDYIDN, USUBJIDN, SITEIDN, AGE, SEXN, RACEN, COHORT, ROUTEN
+    STUDYIDN, USUBJIDN, SITEIDN, COUNTRY, COUNTRYN, AGE, SEXN, RACEN, COHORT, ROUTEN
   )
 )
 
@@ -948,7 +957,7 @@ covar_vslb <- covar %>%
   ) %>%
   rename(TBILBL = BILIBL)
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   covar_vslb,
   display_vars = exprs(
@@ -967,7 +976,7 @@ adppk <- adppk_aseq %>%
   arrange(STUDYIDN, USUBJIDN, AFRLT, EVID) %>%
   mutate(RECSEQ = row_number())
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adppk,
   display_vars = exprs(
