@@ -23,7 +23,7 @@ adsl <- admiral_adsl
 # When SAS datasets are imported into R using haven::read_sas(), missing
 # character values from SAS appear as "" characters in R, instead of appearing
 # as NA values. Further details can be obtained via the following link:
-# https://pharmaverse.github.io/admiral/cran-release/articles/admiral.html#handling-of-missing-values # nolint
+# https://pharmaverse.github.io/admiral/articles/admiral.html#handling-of-missing-values # nolint
 
 ex <- convert_blanks_to_na(ex)
 
@@ -118,36 +118,47 @@ adex <- adex %>%
     derivation = derive_param_exposure,
     variable_params = list(
       params(
-        set_values_to = exprs(PARAMCD = "TDOSE", PARCAT1 = "OVERALL"),
-        input_code = "DOSE",
-        analysis_var = AVAL,
-        summary_fun = function(x) sum(x, na.rm = TRUE)
+        set_values_to = exprs(
+          PARAMCD = "TDOSE",
+          PARCAT1 = "OVERALL",
+          AVAL = sum(AVAL, na.rm = TRUE)
+        ),
+        input_code = "DOSE"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "TPDOSE", PARCAT1 = "OVERALL"),
-        input_code = "PLDOSE",
-        analysis_var = AVAL,
-        summary_fun = function(x) sum(x, na.rm = TRUE)
+        set_values_to = exprs(
+          PARAMCD = "TPDOSE",
+          PARCAT1 = "OVERALL",
+          AVAL = sum(AVAL, na.rm = TRUE)
+        ),
+        input_code = "PLDOSE"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "TDURD", PARCAT1 = "OVERALL"),
-        input_code = "DURD",
-        analysis_var = AVAL,
-        summary_fun = function(x) sum(x, na.rm = TRUE)
+        set_values_to = exprs(
+          PARAMCD = "TDURD",
+          PARCAT1 = "OVERALL",
+          AVAL = sum(AVAL, na.rm = TRUE)
+        ),
+        input_code = "DURD"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "TADJ", PARCAT1 = "OVERALL"),
-        input_code = "ADJ",
-        analysis_var = AVALC,
-        summary_fun = function(x) if_else(sum(!is.na(x)) > 0, "Y", NA_character_)
+        set_values_to = exprs(
+          PARAMCD = "TADJ",
+          PARCAT1 = "OVERALL",
+          AVALC = if_else(sum(!is.na(AVALC)) > 0, "Y", NA_character_)
+        ),
+        input_code = "ADJ"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "TADJAE", PARCAT1 = "OVERALL"),
-        input_code = "ADJAE",
-        analysis_var = AVALC,
-        summary_fun = function(x) if_else(sum(!is.na(x)) > 0, "Y", NA_character_)
+        set_values_to = exprs(
+          PARAMCD = "TADJAE",
+          PARCAT1 = "OVERALL",
+          AVALC = if_else(sum(!is.na(AVALC)) > 0, "Y", NA_character_)
+        ),
+        input_code = "ADJAE"
       )
     ),
+    dataset_add = adex,
     by_vars = exprs(STUDYID, USUBJID, !!!adsl_vars)
   ) %>%
   # W2-W24 exposure
@@ -155,37 +166,48 @@ adex <- adex %>%
     derivation = derive_param_exposure,
     variable_params = list(
       params(
-        set_values_to = exprs(PARAMCD = "PDOSE", PARCAT1 = "WEEK 2-24"),
-        input_code = "DOSE",
-        analysis_var = AVAL,
-        summary_fun = function(x) sum(x, na.rm = TRUE)
+        set_values_to = exprs(
+          PARAMCD = "PDOSE",
+          PARCAT1 = "WEEK 2-24",
+          AVAL = sum(AVAL, na.rm = TRUE)
+        ),
+        input_code = "DOSE"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "PPDOSE", PARCAT1 = "WEEK 2-24"),
-        input_code = "PLDOSE",
-        analysis_var = AVAL,
-        summary_fun = function(x) sum(x, na.rm = TRUE)
+        set_values_to = exprs(
+          PARAMCD = "PPDOSE",
+          PARCAT1 = "WEEK 2-24",
+          AVAL = sum(AVAL, na.rm = TRUE)
+        ),
+        input_code = "PLDOSE"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "PDURD", PARCAT1 = "WEEK 2-24"),
-        input_code = "DURD",
-        analysis_var = AVAL,
-        summary_fun = function(x) sum(x, na.rm = TRUE)
+        set_values_to = exprs(
+          PARAMCD = "PDURD",
+          PARCAT1 = "WEEK 2-24",
+          AVAL = sum(AVAL, na.rm = TRUE)
+        ),
+        input_code = "DURD"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "PADJ", PARCAT1 = "WEEK 2-24"),
-        input_code = "ADJ",
-        analysis_var = AVALC,
-        summary_fun = function(x) if_else(sum(!is.na(x)) > 0, "Y", NA_character_)
+        set_values_to = exprs(
+          PARAMCD = "PADJ",
+          PARCAT1 = "WEEK 2-24",
+          AVALC = if_else(sum(!is.na(AVALC)) > 0, "Y", NA_character_)
+        ),
+        input_code = "ADJ"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "PADJAE", PARCAT1 = "WEEK 2-24"),
-        input_code = "ADJAE",
-        analysis_var = AVALC,
-        summary_fun = function(x) if_else(sum(!is.na(x)) > 0, "Y", NA_character_)
+        set_values_to = exprs(
+          PARAMCD = "PADJAE",
+          PARCAT1 = "WEEK 2-24",
+          AVALC = if_else(sum(!is.na(AVALC)) > 0, "Y", NA_character_)
+        ),
+        input_code = "ADJAE"
       )
     ),
-    filter = VISIT %in% c("WEEK 2", "WEEK 24"),
+    dataset_add = adex,
+    filter_add = VISIT %in% c("WEEK 2", "WEEK 24"),
     by_vars = exprs(STUDYID, USUBJID, !!!adsl_vars)
   ) %>%
   # Overall Dose intensity and W2-24 dose intensity
@@ -302,5 +324,10 @@ adex <- adex %>%
 
 # Save output ----
 
-dir <- tempdir() # Change to whichever directory you want to save the dataset in
-saveRDS(adex, file = file.path(dir, "adex.rds"), compress = "bzip2")
+# Change to whichever directory you want to save the dataset in
+dir <- tools::R_user_dir("admiral_templates_data", which = "cache")
+if (!file.exists(dir)) {
+  # Create the folder
+  dir.create(dir, recursive = TRUE, showWarnings = FALSE)
+}
+save(adex, file = file.path(dir, "adex.rda"), compress = "bzip2")
