@@ -23,7 +23,7 @@ adsl <- admiral_adsl
 # When SAS datasets are imported into R using haven::read_sas(), missing
 # character values from SAS appear as "" characters in R, instead of appearing
 # as NA values. Further details can be obtained via the following link:
-# https://pharmaverse.github.io/admiral/cran-release/articles/admiral.html#handling-of-missing-values # nolint
+# https://pharmaverse.github.io/admiral/articles/admiral.html#handling-of-missing-values # nolint
 
 lb <- convert_blanks_to_na(lb)
 
@@ -37,7 +37,7 @@ param_lookup <- tibble::tribble(
   "ALT", "ALT", "Alanine Aminotransferase (U/L)", 3,
   "ANISO", "ANISO", "Anisocytes", 4,
   "AST", "AST", "Aspartate Aminotransferase (U/L)", 5,
-  "BASO", "BASO", "Basophils (10^9/L)", 6,
+  "BASO", "BASO", "Basophils Abs (10^9/L)", 6,
   "BASOLE", "BASOLE", "Basophils/Leukocytes (FRACTION)", 7,
   "BILI", "BILI", "Bilirubin (umol/L)", 8,
   "BUN", "BUN", "Blood Urea Nitrogen (mmol/L)", 9,
@@ -56,7 +56,7 @@ param_lookup <- tibble::tribble(
   "HGB", "HGB", "Hemoglobin (mmol/L)", 22,
   "K", "POTAS", "Potassium (mmol/L)", 23,
   "KETONES", "KETON", "Ketones", 24,
-  "LYM", "LYMPH", "Lymphocytes (10^9/L)", 25,
+  "LYM", "LYMPH", "Lymphocytes Abs (10^9/L)", 25,
   "LYMLE", "LYMPHLE", "Lymphocytes/Leukocytes (FRACTION)", 26,
   "MACROCY", "MACROC", "Macrocytes", 27,
   "MCH", "MCH", "Ery. Mean Corpuscular Hemoglobin (fmol(Fe))", 28,
@@ -115,7 +115,12 @@ adlb <- adlb %>%
   mutate(
     PARCAT1 = LBCAT,
     AVAL = LBSTRESN,
-    AVALC = LBSTRESC,
+    # Only populate AVALC if character value is non-redundant with AVAL
+    AVALC = ifelse(
+      is.na(LBSTRESN) | as.character(LBSTRESN) != LBSTRESC,
+      LBSTRESC,
+      NA
+    ),
     ANRLO = LBSTNRLO,
     ANRHI = LBSTNRHI
   )
@@ -153,7 +158,7 @@ adlb <- adlb %>%
 
 ## Get Visit Info ----
 # See also the "Visit and Period Variables" vignette
-# (https://pharmaverse.github.io/admiral/cran-release/articles/visits_periods.html#visits)
+# (https://pharmaverse.github.io/admiral/articles/visits_periods.html#visits)
 adlb <- adlb %>%
   # Derive Timing
   mutate(
@@ -229,7 +234,7 @@ adlb <- adlb %>%
 
 # Assign ATOXDSCL and ATOXDSCH to hold lab grading terms
 # ATOXDSCL and ATOXDSCH hold terms defined by NCI-CTCAEv4.
-# See (https://pharmaverse.github.io/admiral/cran-release/articles/lab_grading.html#implement_ctcv4)
+# See (https://pharmaverse.github.io/admiral/articles/lab_grading.html#implement_ctcv4)
 grade_lookup <- tibble::tribble(
   ~PARAMCD, ~ATOXDSCL, ~ATOXDSCH,
   "ALB", "Hypoalbuminemia", NA_character_,
@@ -257,7 +262,7 @@ grade_lookup <- tibble::tribble(
 # user could change to atoxgr_criteria_ctcv5 to implement NCI-CTCAEv5
 # Note: Hyperglycemia and Hypophosphatemia not defined in NCI-CTCAEv5 so
 # user would need to amend look-up table grade_lookup
-# See (https://pharmaverse.github.io/admiral/cran-release/articles/lab_grading.html#implement_ctcv5)
+# See (https://pharmaverse.github.io/admiral/articles/lab_grading.html#implement_ctcv5)
 grade_crit <- atoxgr_criteria_ctcv4
 
 
@@ -368,7 +373,7 @@ adlb <- adlb %>%
 
 ## Get treatment information ----
 # See also the "Visit and Period Variables" vignette
-# (https://pharmaverse.github.io/admiral/cran-release/articles/visits_periods.html#treatment_bds)
+# (https://pharmaverse.github.io/admiral/articles/visits_periods.html#treatment_bds)
 adlb <- adlb %>%
   # Assign TRTA, TRTP
   mutate(
@@ -380,11 +385,11 @@ adlb <- adlb %>%
 adlb <- adlb %>%
   # get MINIMUM value
   derive_extreme_records(
+    dataset_add = adlb,
     by_vars = exprs(STUDYID, USUBJID, PARAMCD, BASETYPE),
     order = exprs(AVAL, ADT, AVISITN),
     mode = "first",
-    # "AVISITN < 9997" to evaluate only real visits
-    filter_add = (!is.na(AVAL) & ONTRTFL == "Y" & AVISITN < 9997),
+    filter_add = (!is.na(AVAL) & ONTRTFL == "Y"),
     set_values_to = exprs(
       AVISITN = 9997,
       AVISIT = "POST-BASELINE MINIMUM",
@@ -393,11 +398,11 @@ adlb <- adlb %>%
   ) %>%
   # get MAXIMUM value
   derive_extreme_records(
+    dataset_add = adlb,
     by_vars = exprs(STUDYID, USUBJID, PARAMCD, BASETYPE),
     order = exprs(desc(AVAL), ADT, AVISITN),
     mode = "first",
-    # "AVISITN < 9997" to evaluate only real visits
-    filter_add = (!is.na(AVAL) & ONTRTFL == "Y" & AVISITN < 9997),
+    filter_add = (!is.na(AVAL) & ONTRTFL == "Y"),
     set_values_to = exprs(
       AVISITN = 9998,
       AVISIT = "POST-BASELINE MAXIMUM",
@@ -406,11 +411,11 @@ adlb <- adlb %>%
   ) %>%
   # get LOV value
   derive_extreme_records(
+    dataset_add = adlb,
     by_vars = exprs(STUDYID, USUBJID, PARAMCD, BASETYPE),
     order = exprs(ADT, AVISITN),
     mode = "last",
-    # "AVISITN < 9997" to evaluate only real visits
-    filter_add = (ONTRTFL == "Y" & AVISITN < 9997),
+    filter_add = (ONTRTFL == "Y"),
     set_values_to = exprs(
       AVISITN = 9999,
       AVISIT = "POST-BASELINE LAST",
@@ -441,5 +446,10 @@ adlb <- adlb %>%
 
 # Save output ----
 
-dir <- tempdir() # Change to whichever directory you want to save the dataset in
-saveRDS(adlb, file = file.path(dir, "adlb.rds"), compress = "bzip2")
+# Change to whichever directory you want to save the dataset in
+dir <- tools::R_user_dir("admiral_templates_data", which = "cache")
+if (!file.exists(dir)) {
+  # Create the folder
+  dir.create(dir, recursive = TRUE, showWarnings = FALSE)
+}
+save(adlb, file = file.path(dir, "adlb.rda"), compress = "bzip2")
