@@ -325,7 +325,7 @@ test_that("derive_param_tte Test 4: error is issued if DTC variables specified f
         PARAM = "Time to First Adverse Event"
       )
     ),
-    regexp = "`AESTDTC` in dataset `ae` is not a date or datetime variable but is a character vector" # nolint
+    class = "assert_date_var"
   )
 })
 
@@ -449,7 +449,7 @@ test_that("derive_param_tte Test 6: an error is issued if some of the by variabl
     )
   )
 
-  expect_error(
+  expect_snapshot(
     derive_param_tte(
       dataset_adsl = adsl,
       by_vars = exprs(AEBODSYS, AEDECOD),
@@ -464,7 +464,7 @@ test_that("derive_param_tte Test 6: an error is issued if some of the by variabl
         PARCAT2 = AEDECOD
       )
     ),
-    regexp = "^Only AEDECOD are included in source dataset.*"
+    error = TRUE
   )
 })
 
@@ -510,7 +510,7 @@ test_that("derive_param_tte Test 7: errors if all by vars are missing in all sou
     )
   )
 
-  expect_error(
+  expect_snapshot(
     derive_param_tte(
       dataset_adsl = adsl,
       by_vars = exprs(AEBODSYS),
@@ -525,8 +525,7 @@ test_that("derive_param_tte Test 7: errors if all by vars are missing in all sou
         PARCAT2 = AEDECOD
       )
     ),
-    regexp = "The by variables (AEBODSYS) are not contained in any of the source datasets.",
-    fixed = TRUE
+    error = TRUE
   )
 })
 
@@ -572,7 +571,7 @@ test_that("derive_param_tte Test 8: errors if PARAMCD and by_vars are not one to
     )
   )
 
-  expect_error(
+  expect_snapshot(
     derive_param_tte(
       dataset_adsl = adsl,
       by_vars = exprs(AEDECOD),
@@ -585,11 +584,7 @@ test_that("derive_param_tte Test 8: errors if PARAMCD and by_vars are not one to
         PARCAT2 = AEDECOD
       )
     ),
-    regexp = paste0(
-      "For some values of PARAMCD there is more than one value of AEDECOD.\n",
-      "Call `get_one_to_many_dataset()` to get all one to many values."
-    ),
-    fixed = TRUE
+    error = TRUE
   )
 })
 
@@ -635,7 +630,7 @@ test_that("derive_param_tte Test 9: errors if set_values_to contains invalid exp
     )
   )
 
-  expect_error(
+  expect_snapshot(
     derive_param_tte(
       dataset_adsl = adsl,
       by_vars = exprs(AEDECOD),
@@ -650,17 +645,7 @@ test_that("derive_param_tte Test 9: errors if set_values_to contains invalid exp
         PARCAT2 = AEDECOD
       )
     ),
-    regexp = paste0(
-      "Assigning variables failed!\n",
-      "set_values_to = \\(\n",
-      "  PARAMCD = paste0\\(\"TTAE\", as.numeric\\(as.factor\\(AEDECOD\\)\\)\\)\n",
-      "  PARAM = past\\(\"Time to First\", AEDECOD, \"Adverse Event\"\\)\n",
-      "  PARCAT1 = TTAE\n",
-      "  PARCAT2 = AEDECOD\n",
-      "\\)\n",
-      "Error message:\n",
-      "  .*"
-    )
+    error = TRUE
   )
 })
 
@@ -731,7 +716,7 @@ test_that("derive_param_tte Test 10: error is issued if parameter code already e
         PARAM = "Time to First Adverse Event"
       )
     ),
-    regexp = "^The parameter code 'TTAE' does already exist in `dataset`.$"
+    class = "assert_param_does_not_exist"
   )
 })
 
@@ -904,9 +889,9 @@ test_that("derive_param_tte Test 12: test dataset and dynamic byvars populated",
 # list_tte_source_objects ----
 ## Test 13: error is issued if package does not exist ----
 test_that("list_tte_source_objects Test 13: error is issued if package does not exist", {
-  expect_error(
+  expect_snapshot(
     list_tte_source_objects(package = "tte"),
-    regexp = "No package called 'tte' is installed and hence no `tte_source` objects are available"
+    error = TRUE
   )
 })
 
