@@ -414,32 +414,8 @@ test_that("derive_var_dthcaus Test 8: `dataset` is sorted using the `order` para
   expect_dfs_equal(expected_output, actual_output, keys = "USUBJID")
 })
 
-## Test 9: returns a warning when traceability_vars is used ----
-test_that("derive_var_dthcaus Test 9: returns a warning when traceability_vars is used", {
-  ae <- tibble::tribble(
-    ~STUDYID, ~USUBJID, ~AESEQ, ~AEDECOD, ~AEOUT, ~AEDTHDTC,
-    "TEST01", "PAT01", 12, "SUDDEN DEATH", "FATAL", "2021-04-04"
-  )
-
-  expect_error(
-    src_ae <- dthcaus_source(
-      dataset_name = "ae",
-      filter = AEOUT == "FATAL",
-      date = AEDTHDT,
-      mode = "first",
-      dthcaus = AEDECOD,
-      traceability_vars = exprs(DTHDOM = "AE", DTHSEQ = AESEQ),
-      set_values_to = exprs(
-        DTHDOM = "AE",
-        DTHSEQ = AESEQ
-      )
-    ),
-    class = "lifecycle_error_deprecated"
-  )
-})
-
-## Test 10: multiple observations from different sources ----
-test_that("derive_var_dthcaus Test 10: multiple observations from different sources", {
+## Test 9: multiple observations from different sources ----
+test_that("derive_var_dthcaus Test 9: multiple observations from different sources", {
   expected <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DTHCAUS,
     "TEST01", "PAT01",  "SUDDEN DEATH",
@@ -494,8 +470,8 @@ test_that("derive_var_dthcaus Test 10: multiple observations from different sour
   )
 })
 
-## Test 11: multiple observations from different sources with same date ----
-test_that("derive_var_dthcaus Test 11: multiple observations with same date", {
+## Test 10: multiple observations with same date ----
+test_that("derive_var_dthcaus Test 10: multiple observations with same date", {
   expected <- tibble::tribble(
     ~STUDYID, ~USUBJID, ~DTHCAUS,
     "TEST01", "PAT01",  "SUDDEN DEATH",
@@ -549,3 +525,60 @@ test_that("derive_var_dthcaus Test 11: multiple observations with same date", {
     keys = c("USUBJID")
   )
 })
+
+## Test 11: error if source dataset is not available ----
+test_that("derive_var_dthcaus Test 11: error if source dataset is not available", {
+  adsl <- tibble::tribble(
+    ~STUDYID, ~USUBJID,
+    "TEST01", "PAT01",
+    "TEST01", "PAT02",
+    "TEST01", "PAT03"
+  )
+
+  ae <- tibble::tribble(
+    ~STUDYID, ~USUBJID, ~AESEQ, ~AEDECOD, ~AEOUT, ~AEDTHDTC,
+    "TEST01", "PAT03", 12, "SUDDEN DEATH", "FATAL", "2021-04-04"
+  ) %>%
+    mutate(
+      AEDTHDT = ymd(AEDTHDTC)
+    )
+
+  ds <- tibble::tribble(
+    ~STUDYID, ~USUBJID, ~DSSEQ, ~DSDECOD, ~DSTERM, ~DSSTDTC,
+    "TEST01", "PAT01", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-01",
+    "TEST01", "PAT01", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
+    "TEST01", "PAT01", 3, "ADVERSE EVENT", "ADVERSE EVENT", "2021-12-01",
+    "TEST01", "PAT01", 4, "DEATH", "DEATH DUE TO progression of disease", "2022-02-01",
+    "TEST01", "PAT02", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-02",
+    "TEST01", "PAT02", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
+    "TEST01", "PAT02", 3, "COMPLETED", "PROTOCOL COMPLETED", "2021-12-01",
+    "TEST01", "PAT03", 1, "INFORMED CONSENT OBTAINED", "INFORMED CONSENT OBTAINED", "2021-04-03",
+    "TEST01", "PAT03", 2, "RANDOMIZATION", "RANDOMIZATION", "2021-04-11",
+    "TEST01", "PAT03", 3, "COMPLETED", "PROTOCOL COMPLETED", "2021-12-01"
+  )
+
+  src_ae <- dthcaus_source(
+    dataset_name = "ae",
+    filter = AEOUT == "FATAL",
+    date = AEDTHDT,
+    mode = "first",
+    dthcaus = AEDECOD
+  )
+
+  src_ds <- dthcaus_source(
+    dataset_name = "ds",
+    filter = DSDECOD == "DEATH" & grepl("DEATH DUE TO", DSTERM),
+    date = convert_dtc_to_dt(DSSTDTC),
+    mode = "first",
+    dthcaus = str_to_upper(DSTERM)
+  )
+
+  expect_snapshot(
+    derive_var_dthcaus(
+      adsl,
+      source_datasets = list(ae = ae, dd = ds),
+      src_ae, src_ds
+    ),
+    error = TRUE
+  )
+})
